@@ -18,9 +18,6 @@
 ###############################################################################
 
 initTLNise <- function() {
-    b <- rnorm(10)
-    v <- runif(10)
-    g <- tlnise(b, v, rep(1, 10), seed = -1, N = 1, prnt = FALSE)
-    invisible()
+        .Deprecated("'seed' argument directly in 'tlnise'")
 }
 
