@@ -1,4 +1,4 @@
-library(tlnise)
+suppressPackageStartupMessages(library(tlnise))
 
 ## Check output of tlnise
 
@@ -159,3 +159,25 @@ str(out)
 out$gamma  ## 'est' should be about 0.00128
 
 ######################################################################
+## Test multivariate TLNise
+
+## Some random covariance matrices simulated using the 'bayesm' package
+V <- structure(c(10.1860962947155, 0.969493754514885, 0.969493754514885, 
+                 5.60509388430824, 2.98429825540546, -4.15235831192084, -4.15235831192084, 
+                 5.89530358088919, 5.9303209147463, -3.48383100994277, -3.48383100994277, 
+                 2.18989814288861, 0.940648850845214, 2.67567180320721, 2.67567180320721, 
+                 8.36460227313887, 3.06779431197503, 0.61886091359145, 0.61886091359145, 
+                 1.51696438440572, 2.43478090261727, -0.386199760832219, -0.386199760832219, 
+                 2.9573907303521, 1.17169557433051, 0.924294781827431, 0.924294781827431, 
+                 2.53657603349922, 4.76923917242757, 0.148936630218258, 0.148936630218258, 
+                 1.34982423924493, 0.515299751368239, 0.265641220542506, 0.265641220542506, 
+                 2.77504546518251, 0.702665634909078, 1.34791092935608, 1.34791092935608, 
+                 5.41520321251996), .Dim = c(2L, 2L, 10L))
+
+library(MASS)
+set.seed(2)
+y <- sapply(1:10, function(i) mvrnorm(1, c(0,0), V[,,i]))
+
+out <- tlnise(y, V, seed = 432)
+
+str(out)
